@@ -7,8 +7,7 @@
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#    the Free Software Foundation; version 2 of the License.
 #
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,7 +38,7 @@ class GopherExceptionsTestCase(unittest.TestCase):
         except IOError, e:
             GopherExceptions.log(e)
         self.assertEqual(self.stringfile.getvalue(),
-                         "unknown-address [None/None] IOError: foo\n")
+                         "unknown-address [None/None] EXCEPTION IOError: foo\n")
 
     def testlog_proto_ip(self):
         rfile = StringIO("/NONEXISTANT\n")
@@ -48,7 +47,7 @@ class GopherExceptionsTestCase(unittest.TestCase):
         handler.handle()
         # handler.handle()
         self.assertEquals(self.stringfile.getvalue(),
-             "10.77.77.77 [GopherProtocol/None] FileNotFound: '/NONEXISTANT' does not exist (no handler found)\n")
+             "10.77.77.77 [GopherProtocol/None] EXCEPTION FileNotFound: '/NONEXISTANT' does not exist (no handler found)\n")
 
     def testFileNotFound(self):
         try:
