@@ -5,8 +5,7 @@
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#    the Free Software Foundation; version 2 of the License.
 #
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +19,6 @@
 import SocketServer
 import re
 import os, stat, os.path, mimetypes, urllib
-from pygopherd import protocols, handlers
 
 mapping = None
 eaexts = None
@@ -51,7 +49,11 @@ class GopherEntry:
         self.ea = {}                    # Extended attributes -- Gopher+
                                         # Abstract, etc.
 
-    def populatefromfs(self, fspath, statval = None):
+    def populatefromvfs(self, vfs, selector):
+        self.populatefromfs(selector, statval = vfs.stat(selector),
+                            vfs = vfs)
+
+    def populatefromfs(self, fspath, statval = None, vfs = None):
         """Fills in self with data gleaned from the filesystem.
 
         The argument fspath specifies where in the filesystem it will search.
@@ -99,6 +101,9 @@ class GopherEntry:
         self.guesstype() will be called to set it."""
         
         self.fspath = fspath
+        if vfs == None:
+            from pygopherd.handlers.base import VFS_Real
+            vfs = VFS_Real(self.config)
 
         if self.populated:
             return
@@ -111,7 +116,7 @@ class GopherEntry:
 
         if not statval:
             try:
-                statval = os.stat(self.fspath)
+                statval = vfs.stat(self.fspath)
             except OSError:
                 return
         
@@ -128,10 +133,10 @@ class GopherEntry:
         if stat.S_ISDIR(statval[0]):
             self.type = self.type or '1'
             self.mimetype = self.mimetype or 'application/gopher-menu'
-            self.handleeaext(self.fspath + '/') # Add the / so we get /.abs
+            self.handleeaext(self.fspath + '/', vfs) # Add the / so we get /.abs
             return
 
-        self.handleeaext(self.fspath)
+        self.handleeaext(self.fspath, vfs)
 
         self.size = self.size or statval[6]
 
@@ -160,17 +165,20 @@ class GopherEntry:
                 return maprule[1]
         return '0'
 
-    def handleeaext(self, fspath):
+    def handleeaext(self, selector, vfs):
         """Handle getting extended attributes from the filesystem."""
         global eaexts
         if eaexts == None:
             eaexts = eval(self.config.get("GopherEntry", "eaexts"))
+        if vfs == None:
+            from pygopherd.handlers.base import VFS_Real
+            vfs = VFS_Real(self.config)
 
         for extension, blockname in eaexts.items():
             if self.ea.has_key(blockname):
                 continue
             try:
-                rfile = open(fspath + extension, "rt")
+                rfile = vfs.open(selector + extension, "rt")
                 self.setea(blockname, "\n".join(
                            [x.strip() for x in rfile.readlines(20480)]))
             except IOError:
